@@ -1,8 +1,13 @@
 import functools
 import inspect
-from collections import Mapping
 from datetime import datetime
 
+try:
+    from collections import Mapping
+except ImportError:
+    # Python 3.10 Support
+    from collections.abc import Mapping
+
 from mgo_serializer.helpers import DictMapper
 
 __all__ = [
@@ -363,7 +368,8 @@ class ListField(BaseField):
     ALLOWED_TYPES = ['CharField', 'DateTimeField', 'IntField', 'ObjectIdField', 'CustomField', 'BooleanField', 'FloatField']
 
     def __init__(self, type=None, **kwargs):
-        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+        self.type = type
+        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
@@ -372,21 +378,19 @@ class ListField(BaseField):
                     ', '.join(self.ALLOWED_TYPES)
                 )
             )
-
-        self.child = type
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
         if data is not Empty:
-            if not self.child:
+            if not self.type:
                 return data
-            return [self.child.to_internal_value(item) for item in data]
+            return [self.type.to_internal_value(item) for item in data]
         return data
 
     def to_representation(self, value):
-        if not self.child:
+        if not self.type:
             return value
-        return [self.child.to_representation(item) for item in value]
+        return [self.type.to_representation(item) for item in value]
 
     def to_protobuf(self, value):
         _repr = self.to_representation(value)
@@ -400,7 +404,8 @@ class DictField(BaseField):
     ALLOWED_TYPES = ['ListField']
 
     def __init__(self, type=None, **kwargs):
-        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+        self.type = type
+        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
@@ -410,24 +415,23 @@ class DictField(BaseField):
                 )
             )
 
-        self.child = type
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
         if data is not Empty:
-            if not self.child:
+            if not self.type:
                 return data
             return {
-                key: self.child.to_internal_value(value)
+                key: self.type.to_internal_value(value)
                 for key, value in data.items()
             }
         return data
 
     def to_representation(self, value):
-        if not self.child:
+        if not self.type:
             return value
         return {
-            key: self.child.to_representation(item)
+            key: self.type.to_representation(item)
             for key, item in value.items()
         }
 
@@ -440,8 +444,8 @@ class DictField(BaseField):
 
 class DateTimeField(BaseField):
 
-    def __init__(self, format=None, **kwargs):
-        self.format = format or '%Y-%m-%d %H:%M:%S'
+    def __init__(self, format='%Y-%m-%dT%H:%M:%S', **kwargs):
+        self.format = format
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
@@ -474,7 +478,8 @@ class TimestampField(BaseField):
     ALLOWED_TYPES = ['IntField', 'CharField', 'FloatField']
 
     def __init__(self, type=None, **kwargs):
-        if type.__class__.__name__ not in self.ALLOWED_TYPES:
+        self.type = IntField() if type is None else type
+        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
@@ -483,8 +488,6 @@ class TimestampField(BaseField):
                     ', '.join(self.ALLOWED_TYPES)
                 )
             )
-
-        self.type = type or IntField()
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
